# Copyright (c) 2016, Camptocamp SA
# All rights reserved.

# Auto-generated file. Do not Edit!
INFO = {
    "git_hash": "f7b23e3f3a81128acf0e266ab2c6146c5589bff3",
    "version": "2.0",
    "git_tag": "2.1.0.dev15",
}
